@@ -2,7 +2,7 @@
 ------------------------
 
 This replaces any explicit float by a Decimal.
-It can be used either as an custom codec or import hook.
+It can be used either as a custom codec or import hook.
 
 The source is assumed to be actually encoded in utf-8.
 """
@@ -17,7 +17,7 @@ def source_init():
     return "from decimal import Decimal\n"
 
 
-def transform_source(source, **kwargs):
+def transform_source(source, **_kwargs):
     """Simple transformation: replaces any explicit float by a Decimal.
 
     By defining this function, we can also make use of Ideas' console.
@@ -38,12 +38,11 @@ def register():
     )
 
 
-def add_hook(verbose_finder=False):
+def add_hook(**_kwargs):
     """Creates and automatically adds the import hook in sys.meta_path"""
     hook = import_hook.create_hook(
         hook_name=__name__,
         source_init=source_init,
         transform_source=transform_source,
-        verbose_finder=verbose_finder,
     )
     return hook
