@@ -15,7 +15,7 @@ PREFIX_SHOWN = False
 
 
 def transform_source(
-    source, callback_params=None, filename=None, module=None, **kwargs
+    source, callback_params=None, filename=None, module=None, **_kwargs
 ):
     """This function is called by the import hook loader with the named keyword
     that we specified when we created the import hook.
@@ -70,7 +70,7 @@ def transform_source(
     source = transform_units(source, prefix)
 
     if callback_params["show_transformed"] and original != source:
-        utils.print_source(source, "Transformed")
+        utils.print_source(source, "New")
 
     return source
 
@@ -88,7 +88,8 @@ def transform_units(source, prefix=""):
     prev_is_identifier = prev_token.is_identifier()
 
     for token in tokens[1:]:
-        # Take note of the token type before possibly changing its
+        # Take note of the token type before possibly changing its nature
+        # by modifying its string value.
         is_identifier = token.is_identifier()
         is_number = token.is_number()
 
@@ -122,14 +123,15 @@ def transform_units(source, prefix=""):
             token.string = "**"
 
         new_tokens.append(token)
-        prev_token = token
         prev_is_number = is_number
         prev_is_identifier = is_identifier
 
     return token_utils.untokenize(new_tokens)
 
 
-def add_hook(show_original=False, show_transformed=False, verbose_finder=False):
+def add_hook(
+    show_original=False, show_transformed=False, verbose_finder=False, **_kwargs
+):
     """Creates and automatically adds the import hook in sys.meta_path"""
     callback_params = {
         "show_original": show_original,
