@@ -11,10 +11,18 @@ import sys
 from importlib.abc import Loader, MetaPathFinder
 from importlib.util import spec_from_file_location, decode_source
 
-from . import console, main_hack
+from . import console
 from .utils import shorten_path, PYTHON, IDEAS, SITE_PACKAGES
 
 
+# Identify the main script assuming that it has been called from
+# the command line using something like
+# python -m ideas main_script[.py] -some_flag
+MAIN_NAME = None
+if len(sys.argv) > 1 and not sys.argv[1].startswith("-"):
+    MAIN_NAME = sys.argv[1].rstrip(".py")
+
+
 class IdeasMetaFinder(MetaPathFinder):
     """A custom finder to locate modules. The main reason for this code
     is to ensure that our custom loader, which does the code transformations,
@@ -138,9 +146,14 @@ class IdeasLoader(Loader):
         """Import the source code, transform it before executing it so that
         it is known to Python.
         """
-        if module.__name__ is not None and module.__name__ == main_hack.main_name:
+        # The main script should be the very first one imported.
+        # To avoid potential named conflicts, we ensure that the potential
+        # identification is only done once.
+        global MAIN_NAME
+        if module.__name__ is not None and module.__name__ == MAIN_NAME:
             module.__name__ = "__main__"
-            main_hack.main_name = None
+        MAIN_NAME = None
+
         if self.module_class is not None:
             module.__class__ = self.module_class
 
@@ -194,6 +207,7 @@ class IdeasLoader(Loader):
 
 
 def create_hook(
+    ipython_ast_node_transformer=None,
     callback_params=None,
     create_module=None,
     console_dict=None,
@@ -255,12 +269,34 @@ def create_hook(
         transform_bytecode=transform_bytecode,
         transform_source=transform_source,
     )
+    if transform_source is not None:
+        try:
+            ip = get_ipython()  # noqa
+            ipython_source_transformer = make_ipython_source_transformer(transform_source)
+            ip.input_transformers_post.append(ipython_source_transformer)
+        except NameError:
+            pass
+
+    if ipython_ast_node_transformer is not None:
+        try:
+            ip = get_ipython()  # noqa
+            ip.ast_transformers.append(ipython_ast_node_transformer)
+        except NameError:
+            pass
 
     return hook
 
+def make_ipython_source_transformer(transform_source):
+    def ipython_source_transformer(lines):
+        source = "".join(lines)
+        source = transform_source(source)
+        lines = source.splitlines(keepends=True)
+        return lines
+    return ipython_source_transformer
+
 
 def remove_hook(hook):
-    """Function used to remove a previously import hook inserted in sys.meta_path"""
+    """Function used to remove a previously imported hook inserted in sys.meta_path"""
     for index, h in enumerate(sys.meta_path):
         if h == hook:
             break
