@@ -29,7 +29,7 @@ def test_transform():
         del _1
         other_code"""
 
-    result = switch.convert_switch(source, predictable_names=True)
+    result = switch.transform_source(source, callback_params={"predictable_names": True})
     assert result == expected, "Switch conversion test"
 
 
@@ -44,7 +44,7 @@ def test_switch1():
     remove_hook(hook)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     test_transform()
     test_switch1()
     print("Done.")
